#!/usr/bin/env pwsh

# save args and first parameter
$ARGS = $args
$ARG1 = $args[0]
# parent dir of this script (should be the getdown app dir)
$DIR = Split-Path $MyInvocation.MyCommand.Path -Parent

# insert an "-open" parameter to Jalview's ARGS if ARG1 is non-zero-length, and not "open" or starts with a "-"
if ( $ARG1.length -gt 0 -and ( -not $ARG1.StartsWith("-") ) -and $ARG1 -cne "open" ) {
  $ARGS = "-open " + $ARGS
}

$APPDIR = $DIR
$JAVAEXE = ( $IsWindows ? "java.exe" : "java" )
$JAVA = Join-Path -Path $APPDIR -ChildPath ( "jre/" + ( $IsMacOs ? "Contents/Home/" : "" ) + "bin/${JAVAEXE}" )
$GETDOWNTXT = Join-Path -Path $APPDIR -ChildPath "getdown.txt"

Write-Host "JAVA=$JAVA"
# look for getdown.txt -- needed to create classpath
if ( -not ( Test-Path -Path "${GETDOWNTXT}" ) ) {
  throw "Cannot find getdown.txt"
}

# look for bundled JRE. Might not be there if unix installer used in which case just invoke "java"
if ( -not ( Test-Path -Path "${JAVA}" ) ) {
  Write-Host "Cannot find bundled ${JAVAEXE}. Using system ${JAVAEXE} and hoping for the best!"
  $JAVA = $JAVAEXE
}

$CLASSPATH = ( Select-String -Path "${GETDOWNTXT}" -AllMatches -Pattern "code\s*=\s*(.*)$" | foreach { Join-Path -Path $DIR -ChildPath $($_.Matches.Groups[1].Value ) } ) -join ( $IsWindows ? ";" : ":" )

Invoke-Expression -Command "${JAVA} -cp '${CLASSPATH}' jalview.bin.Launcher $ARGS"

